file

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

The file package provides helpers for creating temporary files in automated test cases.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Create

func Create(t *testing.T, path string) (*os.File, string)

Create a new file in a new test directory and return the open file pointer and its path.

func CreateEmpty

func CreateEmpty(t *testing.T, path string) string

Create an empty file in a new test directory and return its path.

func NewPath

func NewPath(t *testing.T, path string) string

Create a new test directory and it join with path.

Types

This section is empty.

Jump to