Documentation
¶
Overview ¶
The file package provides helpers for creating temporary files in automated test cases.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
Create a new file in a new test directory and return the open file pointer and its path.
func CreateEmpty ¶
Create an empty file in a new test directory and return its path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.